<?php

defined('ABSPATH') or die;

/*
 *
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
 */
require_once( dirname( __FILE__ ) . '/options/options.php' );

/*
 * 
 * Add support tab
 *
 */
if ( ! defined('MTS_THEME_WHITE_LABEL') || ! MTS_THEME_WHITE_LABEL ) {
	require_once( dirname( __FILE__ ) . '/options/support.php' );
	$mts_options_tab_support = MTS_Options_Tab_Support::get_instance();
}

/*
 *
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){
	
	//$sections = array();
	$sections[] = array(
		'title' => __('A Section added by hook', 'viral' ),
		'desc' => '<p class="description">' . __('This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.', 'viral' ) . '</p>',
		//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		//You dont have to though, leave it blank for default.
		'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
		//Lets leave this as a blank section, no options just some intro text set above.
		'fields' => array()
	);
	
	return $sections;
	
}//function
//add_filter('nhp-opts-sections-twenty_eleven', 'add_another_section');


/*
 * 
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){
	
	//$args['dev_mode'] = false;
	
	return $args;
	
}//function
//add_filter('nhp-opts-args-twenty_eleven', 'change_framework_args');

/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
 */

function setup_framework_options(){
	$args = array();

	//Set it to dev mode to view the class settings/info in the form - default is false
	$args['dev_mode'] = false;
	//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
	//$args['stylesheet_override'] = true;

	//Add HTML before the form
	//$args['intro_text'] = __('<p>This is the HTML which can be displayed before the form, it isnt required, but more info is always better. Anything goes in terms of markup here, any HTML.</p>', 'viral' );

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Setup custom links in the footer for share icons
		$args['share_icons']['twitter'] = array(
			'link' => 'http://twitter.com/mythemeshopteam',
			'title' => __( 'Follow Us on Twitter', 'viral' ),
			'img' => 'fa fa-twitter-square'
		);
		$args['share_icons']['facebook'] = array(
			'link' => 'http://www.facebook.com/mythemeshop',
			'title' => __( 'Like us on Facebook', 'viral' ),
			'img' => 'fa fa-facebook-square'
		);
	}

	//Choose to disable the import/export feature
	//$args['show_import_export'] = false;

	//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
	$args['opt_name'] = MTS_THEME_NAME;

	//Custom menu icon
	//$args['menu_icon'] = '';

	//Custom menu title for options page - default is "Options"
	$args['menu_title'] = __('Theme Options', 'viral' );

	//Custom Page Title for options page - default is "Options"
	$args['page_title'] = __('Theme Options', 'viral' );

	//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options"
	$args['page_slug'] = 'theme_options';

	//Custom page capability - default is set to "manage_options"
	//$args['page_cap'] = 'manage_options';

	//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
	//$args['page_type'] = 'submenu';

	//parent menu - default is set to "themes.php" (Appearance)
	//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	//$args['page_parent'] = 'themes.php';

	//custom page location - default 100 - must be unique or will override other items
	$args['page_position'] = 62;

	//Custom page icon class (used to override the page icon next to heading)
	//$args['page_icon'] = 'icon-themes';

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-1',
			'title' => __('Support', 'viral' ),
			'content' => '<p>' . sprintf( __('If you are facing any problem with our theme or theme option panel, head over to our %s.', 'viral' ), '<a href="http://community.mythemeshop.com/">'. __( 'Support Forums', 'viral' ) . '</a>' ) . '</p>'
		);
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-2',
			'title' => __('Earn Money', 'viral' ),
			'content' => '<p>' . sprintf( __('Earn 70%% commision on every sale by refering your friends and readers. Join our %s.', 'viral' ), '<a href="http://mythemeshop.com/affiliate-program/">' . __( 'Affiliate Program', 'viral' ) . '</a>' ) . '</p>'
		);
	}

	//Set the Help Sidebar for the options page - no sidebar by default										
	//$args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'viral' );

	$mts_patterns = array(
		'nobg' => array('img' => NHP_OPTIONS_URL.'img/patterns/nobg.png'),
		'pattern0' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern0.png'),
		'pattern1' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern1.png'),
		'pattern2' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern2.png'),
		'pattern3' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern3.png'),
		'pattern4' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern4.png'),
		'pattern5' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern5.png'),
		'pattern6' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern6.png'),
		'pattern7' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern7.png'),
		'pattern8' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern8.png'),
		'pattern9' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern9.png'),
		'pattern10' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern10.png'),
		'pattern11' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern11.png'),
		'pattern12' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern12.png'),
		'pattern13' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern13.png'),
		'pattern14' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern14.png'),
		'pattern15' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern15.png'),
		'pattern16' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern16.png'),
		'pattern17' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern17.png'),
		'pattern18' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern18.png'),
		'pattern19' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern19.png'),
		'pattern20' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern20.png'),
		'pattern21' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern21.png'),
		'pattern22' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern22.png'),
		'pattern23' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern23.png'),
		'pattern24' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern24.png'),
		'pattern25' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern25.png'),
		'pattern26' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern26.png'),
		'pattern27' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern27.png'),
		'pattern28' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern28.png'),
		'pattern29' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern29.png'),
		'pattern30' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern30.png'),
		'pattern31' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern31.png'),
		'pattern32' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern32.png'),
		'pattern33' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern33.png'),
		'pattern34' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern34.png'),
		'pattern35' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern35.png'),
		'pattern36' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern36.png'),
		'pattern37' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern37.png'),
		'hbg' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg.png'),
		'hbg2' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg2.png'),
		'hbg3' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg3.png'),
		'hbg4' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg4.png'),
		'hbg5' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg5.png'),
		'hbg6' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg6.png'),
		'hbg7' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg7.png'),
		'hbg8' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg8.png'),
		'hbg9' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg9.png'),
		'hbg10' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg10.png'),
		'hbg11' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg11.png'),
		'hbg12' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg12.png'),
		'hbg13' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg13.png'),
		'hbg14' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg14.png'),
		'hbg15' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg15.png'),
		'hbg16' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg16.png'),
		'hbg17' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg17.png'),
		'hbg18' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg18.png'),
		'hbg19' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg19.png'),
		'hbg20' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg20.png'),
		'hbg21' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg21.png'),
		'hbg22' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg22.png'),
		'hbg23' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg23.png'),
		'hbg24' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg24.png'),
		'hbg25' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg25.png')
	);

	$sections = array();

	$sections[] = array(
		'icon' => 'fa fa-cogs',
		'title' => __('General Settings', 'viral' ),
		'desc' => '<p class="description">' . __('This tab contains common setting options which will be applied to the whole theme.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_logo',
				'type' => 'upload',
				'title' => __('Logo Image', 'viral' ),
				'sub_desc' => sprintf( __('Upload your logo of recommended height %s using the upload Button or insert image URL.', 'viral' ), '<strong>40px</strong>' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_favicon',
				'type' => 'upload',
				'title' => __('Favicon', 'viral' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s favicon.', 'viral' ), '<strong>32 x 32 px</strong>' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_touch_icon',
				'type' => 'upload',
				'title' => __('Touch icon', 'viral' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s touch icon for iOS 2.0+ and Android 2.1+ devices.', 'viral' ), '<strong>152 x 152 px</strong>' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_metro_icon',
				'type' => 'upload',
				'title' => __('Metro icon', 'viral' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s IE 10 Metro tile icon.', 'viral' ), '<strong>144 x 144 px</strong>' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_feedburner',
				'type' => 'text',
				'title' => __('FeedBurner URL', 'viral' ),
				'sub_desc' => sprintf( __('Enter your FeedBurner\'s URL here, ex: %s and your main feed (http://example.com/feed) will get redirected to the FeedBurner ID entered here.)', 'viral' ), '<strong>http://feeds.feedburner.com/mythemeshop</strong>' ),
				'validate' => 'url'
			),
			array(
				'id' => 'mts_header_code',
				'type' => 'textarea',
				'title' => __('Header Code', 'viral' ),
				'sub_desc' => wp_kses( __('Enter the code which you need to place <strong>before closing &lt;/head&gt; tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', 'viral' ), array( 'strong' => array() ) )
			),
			array(
				'id' => 'mts_analytics_code',
				'type' => 'textarea',
				'title' => __('Footer Code', 'viral' ),
				'sub_desc' => wp_kses( __('Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', 'viral' ), array( 'strong' => array() ) )
			),
			array(
				'id' => 'mts_pagenavigation_type',
				'type' => 'radio',
				'title' => __('Pagination Type', 'viral' ),
				'sub_desc' => __('Select pagination type.', 'viral' ),
				'options' => array(
					'0'=> __('Default (Next / Previous)', 'viral' ),
					'1' => __('Numbered (1 2 3 4...)', 'viral' ),
					'2' => __( 'AJAX (Load More Button)', 'viral' ),
					'3' => __( 'AJAX (Auto Infinite Scroll)', 'viral' )
				),
				'std' => '0'
			),
			array(
				'id' => 'mts_back_to_top',
				'type' => 'button_set',
				'title' => __('Back to Top button', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Enable or disable back to top button.', 'viral' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_ajax_search',
				'type' => 'button_set',
				'title' => __('AJAX Quick search', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Enable or disable search results appearing instantly below the search form', 'viral' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_responsive',
				'type' => 'button_set',
				'title' => __('Responsiveness', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('MyThemeShop themes are responsive, which means they adapt to tablet and mobile devices, ensuring that your content is always displayed beautifully no matter what device visitors are using. Enable or disable responsiveness using this option.', 'viral' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_rtl',
				'type' => 'button_set',
				'title' => __('Right To Left Language Support', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Enable this option for right-to-left sites.', 'viral' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_shop_products',
				'type' => 'text',
				'title' => __('No. of Products', 'viral' ),
				'sub_desc' => __('Enter the total number of products which you want to show on shop page (WooCommerce plugin must be enabled).', 'viral' ),
				'validate' => 'numeric',
				'std' => '9',
				'class' => 'small-text'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bolt',
		'title' => __('Performance', 'viral' ),
		'desc' => '<p class="description">' . __('This tab contains performance-related options which can help speed up your website.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_prefetching',
				'type' => 'button_set',
				'title' => __('Prefetching', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Enable or disable prefetching. If user is on homepage, then single page will load faster and if user is on single page, homepage will load faster in modern browsers.', 'viral' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_lazy_load',
				'type' => 'button_set_hide_below',
				'title' => __('Lazy Load', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Delay loading of images outside of viewport, until user scrolls to them.', 'viral' ),
				'std' => '0',
				'args' => array('hide' => 2)
				),
				array(
					'id' => 'mts_lazy_load_thumbs',
					'type' => 'button_set',
					'title' => __('Lazy load featured images', 'viral' ),
					'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
					'sub_desc' => __('Enable or disable Lazy load of featured images across site.', 'viral' ),
					'std' => '0'
				),
				array(
					'id' => 'mts_lazy_load_content',
					'type' => 'button_set',
					'title' => __('Lazy load post content images', 'viral' ),
					'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
					'sub_desc' => __('Enable or disable Lazy load of images inside post/page content.', 'viral' ),
					'std' => '0'
			),
			array(
				'id' => 'mts_async_js',
				'type' => 'button_set',
				'title' => __('Async JavaScript', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => sprintf( __('Add %s attribute to script tags to improve page download speed.', 'viral' ), '<code>async</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_remove_ver_params',
				'type' => 'button_set',
				'title' => __('Remove ver parameters', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => sprintf( __('Remove %s parameter from CSS and JS file calls. It may improve speed in some browsers which do not cache files having the parameter.', 'viral' ), '<code>ver</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_optimize_wc',
				'type' => 'button_set',
				'title' => __('Optimize WooCommerce scripts', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Load WooCommerce scripts and styles only on WooCommerce pages (WooCommerce plugin must be enabled).', 'viral' ),
				'std' => '1'
			),
			'cache_message' => array(
				'id' => 'mts_cache_message',
				'type' => 'info',
				'title' => __('Use Cache', 'viral' ),
				// Translators: %1$s = popup link to W3 Total Cache, %2$s = popup link to WP Super Cache
				'desc' => sprintf(
					__('A cache plugin can increase page download speed dramatically. We recommend using %1$s or %2$s.', 'viral' ),
					'<a href="https://community.mythemeshop.com/tutorials/article/8-make-your-website-load-faster-using-w3-total-cache-plugin/" target="_blank" title="W3 Total Cache">W3 Total Cache</a>',
					'<a href="'.admin_url( 'plugin-install.php?tab=plugin-information&plugin=wp-super-cache&TB_iframe=true&width=772&height=574' ).'" class="thickbox" title="WP Super Cache">WP Super Cache</a>'
				),
			),
		)
	);

	// Hide cache message on multisite or if a chache plugin is active already
	if ( is_multisite() || strstr( join( ';', get_option( 'active_plugins' ) ), 'cache' ) ) {
		unset( $sections[1]['fields']['cache_message'] );
	}

	$sections[] = array(
		'icon' => 'fa fa-adjust',
		'title' => __('Styling Options', 'viral' ),
		'desc' => '<p class="description">' . __('Control the visual appearance of your theme, such as colors, layout and patterns, from here.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_color_scheme',
				'type' => 'color',
				'title' => __('Color Scheme', 'viral' ),
				'sub_desc' => __('The theme comes with unlimited color schemes for your theme\'s styling.', 'viral' ),
				'std' => '#e84a5f'
			),
			array(
				'id' => 'mts_layout',
				'type' => 'radio_img',
				'title' => __('Layout Style', 'viral' ),
				'sub_desc' => wp_kses( __('Choose the <strong>default sidebar position</strong> for your site. The position of the sidebar for individual posts can be set in the post editor.', 'viral' ), array( 'strong' => array() ) ),
				'options' => array(
					'cslayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/cs.png'),
					'sclayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/sc.png')
				),
				'std' => 'cslayout'
			),
			array(
				'id' => 'mts_background',
				'type' => 'background',
				'title' => __('Site Background', 'viral' ),
				'sub_desc' => __('Set background color, pattern and image from here.', 'viral' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_custom_css',
				'type' => 'textarea',
				'title' => __('Custom CSS', 'viral' ),
				'sub_desc' => __('You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', 'viral' )
			),
			array(
				'id' => 'mts_lightbox',
				'type' => 'button_set',
				'title' => __('Lightbox', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('A lightbox is a stylized pop-up that allows your visitors to view larger versions of images without leaving the current page. You can enable or disable the lightbox here.', 'viral' ),
				'std' => '0'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-credit-card',
		'title' => __('Header', 'viral' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of header section.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_show_primary_nav',
				'type' => 'button_set_hide_below',
				'title' => __('Show Primary Menu', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'viral' ), '<strong>' . __( 'Primary Navigation Menu', 'viral' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_search',
				'type' => 'button_set',
				'title' => __('Show Header Search', 'viral' ), 
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Use this button to enable <strong>Header Search</strong>.', 'viral' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_primary_nav_background',
				'type' => 'background',
				'title' => __('Primary Nav Background', 'viral' ),
				'sub_desc' => __('Set Primary Nav background color, pattern and image from here.', 'viral' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_header_background',
				'type' => 'background',
				'title' => __('Header Background', 'viral' ),
				'sub_desc' => __('Set Header background color, pattern and image from here.', 'viral' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#000000',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_sticky_nav',
				'type' => 'button_set',
				'title' => __('Floating Navigation Menu', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'viral' ), '<strong>' . __('Floating Navigation Menu', 'viral' ) . '</strong>' ),
				'std' => '0'
			),
			
			array(
				'id' => 'mts_header_section2',
				'type' => 'button_set',
				'title' => __('Show Logo', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => wp_kses( __('Use this button to Show or Hide the <strong>Logo</strong> completely.', 'viral' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_show_secondary_nav',
				'type' => 'button_set',
				'title' => __('Show secondary menu', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'viral' ), '<strong>' . __( 'Secondary Navigation Menu', 'viral' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_right',
				'type' => 'multi_checkbox',
				'title' => __('Show right section on Header', 'viral' ),
				'sub_desc' => __('You can enable Random Button, Login Form and Upload Button from here.', 'viral' ),
				'options' => array(
					'random' => __( 'Random Posts Button', 'viral' ),
					'login' => __( 'Login/Signup Links', 'viral' ),
					'upload' => __( 'Upload Button', 'viral' )
				),
				'std' => array('random' => '1', 'login' => '1', 'blog-page' => '1', 'upload' => '1')
			),
			array(
				'id' => 'mts_header_bottom_background',
				'type' => 'background',
				'title' => __('Header Bottom Background', 'viral' ),
				'sub_desc' => __('Set Header bottom background color, pattern and image from here.', 'viral' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#f7f7f7',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id'	 => 'mts_header_buttons',
				'type'	 => 'layout2',
				'title'	=> __('Header Social Media Buttons', 'viral' ),
				'sub_desc' => __('Organize how you want your social sharing buttons to appear on Header', 'viral' ),
				'options'  => array(
					'enabled'  => array(
						'twitter'   => array(
							'label' 	=> __('Twitter', 'viral' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_twitter_username',
									'type' => 'text',
									'class' => 'medium-text',
									'title' => __('Twitter Username', 'viral' ) ,
									'sub_desc' => __('Enter twitter username here without @', 'viral' ) ,
									'std' => 'MyThemeShopTeam',
								),
							)
						),
						'facebook'   => array(
							'label' 	=> __('Facebook', 'viral' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_facebook_url',
									'type' => 'text',
									'class' => 'medium-text',
									'title' => __('Facebook URL', 'viral' ) ,
									'sub_desc' => __('Enter Facebook Profile/Page URL here.', 'viral' ) ,
									'std' => 'https://facebook.com/mythemeshop',
								),
							)
						),
						'gplus'   => array(
							'label' 	=> __('Google+', 'viral' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_gplus_url',
									'type' => 'text',
									'class' => 'medium-text',
									'title' => __('Google+ URL', 'viral' ) ,
									'sub_desc' => __('Enter Google+ Profile/Page URL here.', 'viral' ) ,
									'std' => 'https://mythemeshop.com/',
								),
							)
						),
					),
					'disabled' => array()
				),
				'std'  => array(
					'enabled'  => array(
						'twitter'	 => __('Twitter', 'viral' ),
						'facebook'   => __('Facebook', 'viral' ),
						'gplus'	 => __('Google+', 'viral' )
					),
					'disabled' => array()
				)
			),
			array(
				'id' => 'mts_header_layout_icons',
				'type' => 'button_set_hide_below',
				'title' => __('Show Layout Icons', 'viral' ), 
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Use this button to enable <strong>Post Layout icons</strong>.', 'viral' ),
				'std' => '1'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-table',
		'title' => __('Footer', 'viral' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of Footer section.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_first_footer',
				'type' => 'button_set_hide_below',
				'title' => __('Footer', 'viral' ),
				'sub_desc' => __('Enable or disable footer with this option.', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'std' => '0',
				'args' => array('hide' => 2)
			),
			array(
					'id' => 'mts_first_footer_num',
					'type' => 'button_set',
					'class' => 'green',
					'title' => __('Footer Layout', 'viral' ),
					'sub_desc' => wp_kses( __('Choose the number of widget areas in the <strong>footer</strong>', 'viral' ), array( 'strong' => array() ) ),
					'options' => array(
						'3' => __( '3 Widgets', 'viral' ),
						'4' => __( '4 Widgets', 'viral' ),
					),
					'std' => '4'
			),
			array(
				'id' => 'mts_footer_background',
				'type' => 'background',
				'title' => __('Footer Background', 'viral' ),
				'sub_desc' => __('Set Footer background color, pattern and image from here.', 'viral' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#222222',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_copyrights_background',
				'type' => 'background',
				'title' => __('Copyrights Background', 'viral' ),
				'sub_desc' => __('Set copyrights background color, pattern and image from here.', 'viral' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#111111',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_copyrights',
				'type' => 'textarea',
				'title' => __('Copyrights Text', 'viral' ),
				'sub_desc' => __( 'You can change or remove our link from footer and use your own custom text.', 'viral' ) . ( MTS_THEME_WHITE_LABEL ? '' : wp_kses( __('(You can also use your affiliate link to <strong>earn 70% of sales</strong>. Ex: <a href="https://mythemeshop.com/go/aff/aff" target="_blank">https://mythemeshop.com/?ref=username</a>)', 'viral' ), array( 'strong' => array(), 'a' => array( 'href' => array(), 'target' => array() ) ) ) ),
				'std' => MTS_THEME_WHITE_LABEL ? null : sprintf( __( 'Theme by %s', 'viral' ), '<a href="http://mythemeshop.com/">MyThemeShop</a>' )
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-home',
		'title' => __('Homepage', 'viral' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of the homepage.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_featured_carousel',
				'type' => 'button_set_hide_below',
				'title' => __('Carousel', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => wp_kses( __('<strong>Enable or Disable</strong> homepage carousel with this button. The carousel will show recent articles from the selected categories.', 'viral' ), array( 'strong' => array() ) ),
				'std' => '0',
				'args' => array('hide' => 5)
				),
				array(
					'id' => 'mts_featured_carousel_cat',
					'type' => 'cats_multi_select',
					'title' => __('Carousel Category(s)', 'viral' ),
					'sub_desc' => wp_kses( __('Select a category from the drop-down menu, latest articles from this category will be shown <strong>in the carousel</strong>.', 'viral' ), array( 'strong' => array() ) ),
				),
				array(
					'id' => 'mts_featured_carousel_num',
					'type' => 'text',
					'class' => 'small-text',
					'title' => __('Number of posts', 'viral' ),
					'sub_desc' => __('Enter the number of posts to show in the carousel', 'viral' ),
					'std' => '6',
					'args' => array('type' => 'number')
				),
				array(
					'id' => 'mts_custom_carousel',
					'type' => 'group',
					'title' => __('Custom Carousel', 'viral' ),
					'sub_desc' => __('With this option you can set up a carousel with custom image and text instead of the default carousel automatically generated from your posts.', 'viral' ),
					'groupname' => __('Carousel', 'viral' ), // Group name
					'subfields' =>
					array(
						array(
							'id' => 'mts_custom_carousel_title',
							'type' => 'text',
							'title' => __('Title', 'viral' ),
							'sub_desc' => __('Title of the slide', 'viral' ),
						),
						array(
							'id' => 'mts_custom_carousel_image',
							'type' => 'upload',
							'title' => __('Image', 'viral' ),
							'sub_desc' => __('Upload or select an image for this slide', 'viral' ),
							'return' => 'id'
						),
						array(
							'id' => 'mts_custom_carousel_url',
							'type' => 'text',
							'title' => __('URL', 'viral' ),
							'sub_desc' => __('Add link to the carousel item.', 'viral' ),
						),
					),
				),
				array(
					'id' => 'mts_carousel_position',
					'type' => 'button_set',
					'title' => __('Carousel Position on Homepage', 'viral' ),
					'options' => array('top' => __('After Header', 'viral' ), 'bottom' => __('Before Footer', 'viral' )),
					'sub_desc' => __('Choose position for Carousel on the Homepage.', 'viral' ),
					'std' => 'top',
					'class' => 'green'
				),
				array(
					'id' => 'mts_carousel_pages',
					'type' => 'multi_checkbox',
					'title' => __('Show Carousel on Other Pages', 'viral' ),
					'sub_desc' => __('You can enable carousel on other pages from here.', 'viral' ),
					'options' => array(
						'viral-archive' => __( 'Archive Pages', 'viral' ),
						'viral-single' => __( 'Single Posts', 'viral' )
					),
					'std' => array('viral-archive' => '1', 'viral-single' => '1')
				),
			array(
				'id' => 'mts_featured_categories',
				'type' => 'group',
				'title'	 => __('Featured Categories', 'viral' ),
				'sub_desc'  => __('Select categories appearing on the homepage.', 'viral' ),
				'groupname' => __('Section', 'viral' ), // Group name
				'subfields' => array(
					array(
						'id' => 'mts_featured_category',
						'type' => 'cats_select',
						'title' => __('Category', 'viral' ),
						'sub_desc' => __('Select a category or the latest posts for this section', 'viral' ),
						'std' => 'latest',
						'args' => array('include_latest' => 1, 'hide_empty' => 0),
					),
					array(
						'id' => 'mts_featured_category_postsnum',
						'type' => 'text',
						'class' => 'small-text',
						'title' => __('Number of posts', 'viral' ),
						'sub_desc' => __('Enter the number of posts to show in this section.', 'viral' ),
						'std' => '2',
						'args' => array('type' => 'number')
					),
				),
				'std' => array(
					'1' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_featured_category' => 'latest',
						'mts_featured_category_postsnum' => get_option('posts_per_page')
					)
				)
			),
			array(
				'id' => 'mts_grid_layout',
				'type' => 'radio_img',
				'title' => __('Default Posts Layout', 'viral' ),
				'sub_desc' => wp_kses( __('Choose the <strong>default post layout style</strong> for first time visitors.', 'viral' ), array( 'strong' => array() ) ),
				'options' => array(
					'post-type-1' => array('img' => NHP_OPTIONS_URL.'img/layouts/grid-1.png'),
					'post-type-2' => array('img' => NHP_OPTIONS_URL.'img/layouts/grid-2.png'),
					'post-type-3' => array('img' => NHP_OPTIONS_URL.'img/layouts/grid-3.png')
				),
				'std' => 'post-type-1'
			),
			array(
				'id' => 'mts_full_posts',
				'type' => 'button_set',
				'title' => __('Posts on blog pages', 'viral' ),
				'options' => array('0' => __('Excerpts','viral'),'1' => __('Full posts', 'viral' )),
				'sub_desc' => __('Show post excerpts or full posts on the homepage and other archive pages. This option is recommended for 1st Post Layout only.', 'viral' ),
				'std' => '0',
				'class' => 'green'
			),
			array(
				'id' => 'mts_like_dislike',
				'type' => 'button_set',
				'title' => __('Like/Dislike', 'viral'), 
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Use this button to enable Like &amp; Dislike features for posts.', 'viral'),
				'std' => '1'
			),
			array(
				'id'	 => 'mts_home_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('HomePage Post Meta Info', 'viral' ),
				'sub_desc' => __('Organize how you want the post meta info to appear on the homepage', 'viral' ),
				'options'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'viral' ),
						'date'	 => __('Date', 'viral' ),
						'comments' => __('Comment Count','viral'),
						'views' => __('Views','viral')
					),
					'disabled' => array(
						'category' => __('Categories', 'viral' )
					)
				),
				'std'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'viral' ),
						'date'	 => __('Date', 'viral' ),
						'comments' => __('Comment Count','viral'),
						'views' => __('Views','viral')
					),
					'disabled' => array(
						'category' => __('Categories', 'viral' )
					)
				)
			),
			array(
				'id' => 'mts_author_image',
				'type' => 'button_set',
				'title' => __('Show Author Image', 'viral' ), 
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Show author image in the post meta info.', 'viral' ),
				'std' => '1'
			),
			array(
				'id'	 => 'mts_posts_social_buttons',
				'type'	 => 'layout',
				'title'	=> __('Posts Social Media Buttons', 'viral' ),
				'sub_desc' => __('Organize how you want your social sharing buttons to appear on posts. Note: Whatsapp button will appear on the screens smaller than 1024px.', 'viral' ),
				'options'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'viral' ),
						'twitter'	 => __('Twitter', 'viral' ),
						'gplus'	 => __('Google Plus', 'viral' ),
						'pinterest'	 => __('Pinterest', 'viral' ),
						'whatsapp'  => __('WhatsApp', 'viral' )
					),
					'disabled' => array(
						'stumble'   => __('StumbleUpon', 'viral' ),
						'reddit'   => __('Reddit', 'viral' )
					)
				),
				'std'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'viral' ),
						'twitter'	 => __('Twitter', 'viral' ),
						'gplus'	 => __('Google Plus', 'viral' ),
						'pinterest'	 => __('Pinterest', 'viral' ),
						'whatsapp'  => __('WhatsApp', 'viral' )
					),
					'disabled' => array(
						'stumble'   => __('StumbleUpon', 'viral' ),
						'reddit'   => __('Reddit', 'viral' )
					)
				),
				'reset_at_version' => '1.0.9'
			),
			array(
				'id' => 'mts_homepage_social_button_position',
				'type' => 'button_set',
				'title' => __('HomePage Social Buttons Position', 'viral' ),
				'options' => array('bottom' => __('Below Content', 'viral' ), 'left' => __('Left', 'viral' )),
				'sub_desc' => __('Choose position for HomePage Social Buttons.', 'viral' ),
				'std' => 'bottom',
				'class' => 'green'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-file-text',
		'title' => __('Single Posts', 'viral' ),
		'desc' => '<p class="description">' . __('From here, you can control the appearance and functionality of your single posts page.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id'	 => 'mts_single_post_layout',
				'type'	 => 'layout2',
				'title'	=> __('Single Post Layout', 'viral' ),
				'sub_desc' => __('Customize the look of single posts', 'viral' ),
				'options'  => array(
					'enabled'  => array(
						'content'   => array(
							'label' 	=> __('Post Content', 'viral' ),
							'subfields'	=> array()
						),
						'related'   => array(
							'label' 	=> __('Related Posts', 'viral' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_related_posts_taxonomy',
									'type' => 'button_set',
									'title' => __('Related Posts Taxonomy', 'viral' ) ,
									'options' => array(
										'tags' => __( 'Tags', 'viral' ),
										'categories' => __( 'Categories', 'viral' )
									) ,
									'class' => 'green',
									'sub_desc' => __('Related Posts based on tags or categories.', 'viral' ) ,
									'std' => 'categories'
								),
								array(
									'id' => 'mts_related_postsnum',
									'type' => 'text',
									'class' => 'small-text',
									'title' => __('Number of related posts', 'viral' ) ,
									'sub_desc' => __('Enter the number of posts to show in the related posts section.', 'viral' ) ,
									'std' => '2',
									'args' => array(
										'type' => 'number'
									)
								),

							)
						),
						'author'   => array(
							'label' 	=> __('Author Box', 'viral' ),
							'subfields'	=> array()
						),
					),
					'disabled' => array(
						'tags'   => array(
							'label' 	=> __('Tags', 'viral' ),
							'subfields'	=> array()
						),
					)
				)
			),
			array(
				'id'	 => 'mts_single_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('Single Post Meta Info', 'viral' ),
				'sub_desc' => __('Organize how you want the post meta info to appear on the single post.', 'viral' ),
				'options'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'viral' ),
						'date'	 => __('Date', 'viral' ),
						'comments' => __('Comment Count','viral'),
						'views' => __('Views','viral')
					),
					'disabled' => array(
						'category' => __('Categories', 'viral' )
					)
				),
				'std'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'viral' ),
						'date'	 => __('Date', 'viral' ),
						'comments' => __('Comment Count','viral'),
						'views' => __('Views','viral')
					),
					'disabled' => array(
						'category' => __('Categories', 'viral' )
					)
				)
			),
			array(
				'id' => 'mts_single_author_image',
				'type' => 'button_set',
				'title' => __('Show Author Image', 'viral' ), 
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Show author image in the single post meta info.', 'viral' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_comment_like_dislike',
				'type' => 'button_set',
				'title' => __('Comment Like/Dislike', 'viral'), 
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Use this button to enable Like &amp; Dislike features for commments.', 'viral'),
				'std' => '1'
			),
			array(
				'id' => 'mts_breadcrumb',
				'type' => 'button_set',
				'title' => __('Breadcrumbs', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'viral' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_show_featured',
				'type' => 'button_set',
				'title' => __('Show Featured image', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Enable/Disable the Featured images in the single post.', 'viral' ),
				'std' => '1'
			),
			array(
                'id'       => 'mts_comments',
                'type'     => 'layout2',
                'title'    => __('Comments', 'viral'),
                'sub_desc' => __('Show standard comments, Facebook comments, or both, in tabs layout.', 'viral'),
                'options'  => array(
                    'enabled'  => array(
                        'comments'   => array(
                        	'label' 	=> __('Comments','viral'),
                        	'subfields'	=> array()
                        ),
                        'fb_comments'   => array(
                        	'label' 	=> __('Facebook Comments','viral'),
                        	'subfields'	=> array(
			        			array(
			        				'id' => 'mts_fb_app_id',
			        				'type' => 'text',
			        				'title' => __('Facebook App ID', 'viral'),
									'sub_desc' => __('Enter your Facebook app ID here. You can create Facebook App id <a href="https://developers.facebook.com/apps" target="_blank">here</a>', 'viral'),
			        				'class' => 'small'
			        			),
                        	)
                        ),
                    ),
                    'disabled' => array()
                )
            ),
			array(
				'id' => 'mts_author_comment',
				'type' => 'button_set',
				'title' => __('Highlight Author Comment', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Use this button to highlight author comments.', 'viral' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_comment_date',
				'type' => 'button_set',
				'title' => __('Date in Comments', 'viral' ),
				'options' => array( '0' => __( 'Off', 'viral' ), '1' => __( 'On', 'viral' ) ),
				'sub_desc' => __('Use this button to show the date for comments.', 'viral' ),
				'std' => '1'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-group',
		'title' => __('Social Buttons', 'viral' ),
		'desc' => '<p class="description">' . __('Enable or disable social sharing buttons on single posts using these buttons.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_social_button_layout',
				'type' => 'radio_img',
				'title' => __('Social Sharing Buttons Layout', 'viral' ),
				'sub_desc' => wp_kses( __('Choose default or modern <strong>social sharing buttons</strong> layout on single post & pages', 'viral' ), array( 'strong' => array() ) ),
				'options' => array(
					'default' => array('img' => NHP_OPTIONS_URL.'img/layouts/default-social.jpg'),
					'modern' => array('img' => NHP_OPTIONS_URL.'img/layouts/modern-social.jpg')
				),
				'std' => 'modern',
				'reset_at_version' => '1.0.9'
			),
			array(
				'id' => 'mts_social_button_position',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons Position', 'viral' ),
				'options' => array('top' => __('Above Content', 'viral' ), 'bottom' => __('Below Content', 'viral' ), 'floating' => __('Floating', 'viral' )),
				'sub_desc' => __('Choose position for Social Sharing Buttons.', 'viral' ),
				'std' => 'top',
				'class' => 'green'
			),
			array(
				'id' => 'mts_social_buttons_floating_position',
				'type' => 'text',
				'class' => 'small-text',
				'title' => __('Social Buttons Floating Position from Bottom', 'viral' ),
				'sub_desc' => __('Enter the number. It will set the Floating position from bottom in pixels.', 'viral' ),
				'std' => '200',
				'args' => array('type' => 'number')
			),
			array(
				'id' => 'mts_social_buttons_on_pages',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons on Pages', 'viral' ),
				'options' => array('0' => __('Off', 'viral' ), '1' => __('On', 'viral' )),
				'sub_desc' => __('Enable the sharing buttons for pages too, not just posts.', 'viral' ),
				'std' => '0',
			),
			array(
				'id'   => 'mts_social_buttons',
				'type' => 'layout',
				'title'	=> __('Social Media Buttons', 'viral' ),
				'sub_desc' => __('Organize how you want the social sharing buttons to appear on single posts. Note: Whatsapp button will appear on the screens smaller than 1024px.', 'viral' ),
				'options'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'viral' ),
						'twitter'	 => __('Twitter', 'viral' ),
						'gplus'	 => __('Google Plus', 'viral' ),
						'pinterest'	 => __('Pinterest', 'viral' ),
						'whatsapp'  => __('WhatsApp', 'viral' )
					),
					'disabled' => array(
						'stumble'   => __('StumbleUpon', 'viral' ),
						'reddit'   => __('Reddit', 'viral' ),
					)
				),
				'std'  => array(
					'enabled'  => array(
						'facebookshare'   => __('Facebook Share', 'viral' ),
						'twitter'	 => __('Twitter', 'viral' ),
						'gplus'	 => __('Google Plus', 'viral' ),
						'pinterest'	 => __('Pinterest', 'viral' ),
						'whatsapp'  => __('WhatsApp', 'viral' )
					),
					'disabled' => array(
						'stumble'   => __('StumbleUpon', 'viral' ),
						'reddit'   => __('Reddit', 'viral' ),
					)
				),
				'reset_at_version' => '1.0.9'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bar-chart-o',
		'title' => __('Ad Management', 'viral' ),
		'desc' => '<p class="description">' . __('Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'viral' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_posttop_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Title', 'viral' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', 'viral' )
			),
			array(
				'id' => 'mts_posttop_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'viral' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'viral' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
			array(
				'id' => 'mts_postend_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Content', 'viral' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', 'viral' )
			),
			array(
				'id' => 'mts_postend_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'viral' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'viral' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-columns',
		'title' => __('Sidebars', 'viral' ),
		'desc' => '<p class="description">' . __('Now you have full control over the sidebars. Here you can manage sidebars and select one for each section of your site, or select a custom sidebar on a per-post basis in the post editor.', 'viral' ) . '<br></p>',
		'fields' => array(
			array(
				'id' => 'mts_sidebar_title_background',
				'type' => 'background',
				'title' => __('Sidebar Title Background', 'viral' ),
				'sub_desc' => __('Set sidebar title background color, pattern and image from here.', 'viral' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#f7f7f7',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_custom_sidebars',
				'type'  => 'group', //doesn't need to be called for callback fields
				'title' => __('Custom Sidebars', 'viral' ),
				'sub_desc'  => wp_kses( __('Add custom sidebars. <strong style="font-weight: 800;">You need to save the changes to use the sidebars in the dropdowns below.</strong><br />You can add content to the sidebars in Appearance &gt; Widgets.', 'viral' ), array( 'strong' => array(), 'br' => array() ) ),
				'groupname' => __('Sidebar', 'viral' ), // Group name
				'subfields' => 
					array(
						array(
							'id' => 'mts_custom_sidebar_name',
							'type' => 'text',
							'title' => __('Name', 'viral' ),
							'sub_desc' => __('Example: Homepage Sidebar', 'viral' )
						),	
						array(
							'id' => 'mts_custom_sidebar_id',
							'type' => 'text',
							'title' => __('ID', 'viral' ),
							'sub_desc' => __('Enter a unique ID for the sidebar. Use only alphanumeric characters, underscores (_) and dashes (-), eg. "sidebar-home"', 'viral' ),
							'std' => 'sidebar-'
						),
					),
			),
			array(
				'id' => 'mts_sidebar_for_home',
				'type' => 'sidebars_select',
				'title' => __('Homepage', 'viral' ),
				'sub_desc' => __('Select a sidebar for the homepage.', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_post',
				'type' => 'sidebars_select',
				'title' => __('Single Post', 'viral' ),
				'sub_desc' => __('Select a sidebar for the single posts. If a post has a custom sidebar set, it will override this.', 'viral' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_page',
				'type' => 'sidebars_select',
				'title' => __('Single Page', 'viral' ),
				'sub_desc' => __('Select a sidebar for the single pages. If a page has a custom sidebar set, it will override this.', 'viral' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_archive',
				'type' => 'sidebars_select',
				'title' => __('Archive', 'viral' ),
				'sub_desc' => __('Select a sidebar for the archives. Specific archive sidebars will override this setting (see below).', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_category',
				'type' => 'sidebars_select',
				'title' => __('Category Archive', 'viral' ),
				'sub_desc' => __('Select a sidebar for the category archives.', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_tag',
				'type' => 'sidebars_select',
				'title' => __('Tag Archive', 'viral' ),
				'sub_desc' => __('Select a sidebar for the tag archives.', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_date',
				'type' => 'sidebars_select',
				'title' => __('Date Archive', 'viral' ),
				'sub_desc' => __('Select a sidebar for the date archives.', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_author',
				'type' => 'sidebars_select',
				'title' => __('Author Archive', 'viral' ),
				'sub_desc' => __('Select a sidebar for the author archives.', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_search',
				'type' => 'sidebars_select',
				'title' => __('Search', 'viral' ),
				'sub_desc' => __('Select a sidebar for the search results.', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_notfound',
				'type' => 'sidebars_select',
				'title' => __('404 Error', 'viral' ),
				'sub_desc' => __('Select a sidebar for the 404 Not found pages.', 'viral' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_shop',
				'type' => 'sidebars_select',
				'title' => __('Shop Pages', 'viral' ),
				'sub_desc' => wp_kses( __('Select a sidebar for Shop main page and product archive pages (WooCommerce plugin must be enabled). Default is <strong>Shop Page Sidebar</strong>.', 'viral' ), array( 'strong' => array() ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => 'shop-sidebar'
			),
			array(
				'id' => 'mts_sidebar_for_product',
				'type' => 'sidebars_select',
				'title' => __('Single Product', 'viral' ),
				'sub_desc' => wp_kses( __('Select a sidebar for single products (WooCommerce plugin must be enabled). Default is <strong>Single Product Sidebar</strong>.', 'viral' ), array( 'strong' => array() ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => 'product-sidebar'
			),
		),
	);

	$sections[] = array(
		'icon' => 'fa fa-list-alt',
		'title' => __('Navigation', 'viral' ),
		'desc' => '<p class="description"><div class="controls">' . sprintf( __('Navigation settings can now be modified from the %s.', 'viral' ), '<a href="nav-menus.php"><b>' . __( 'Menus Section', 'viral' ) . '</b></a>' ) . '<br></div></p>'
	);

					
	$tabs = array();

	$args['presets'] = array();
	$args['show_translate'] = false;
	include('theme-presets.php');

	global $NHP_Options;
	$NHP_Options = new NHP_Options($sections, $args, $tabs);

} //function

add_action('init', 'setup_framework_options', 0);

/*
 * 
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	print_r($field);
	print_r($value);

}//function

/*
 * 
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){
	
	$error = false;
	$value =  'just testing';
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;
	
}//function

/*--------------------------------------------------------------------
 * 
 * Default Font Settings
 *
 --------------------------------------------------------------------*/
if(function_exists('mts_register_typography')) {
	mts_register_typography( array(
		'logo_font' => array(
			'preview_text' => __( 'Logo Font', 'viral' ),
			'preview_color' => 'dark',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '46px',
			'font_color' => '#ffffff',
			'css_selectors' => '#logo a'
		),
		'top_navigation_font' => array(
			'preview_text' => __( 'Top Navigation Font', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#666666',
			'css_selectors' => '#primary-navigation a, .top-bar'
		),
		'main_navigation_font' => array(
			'preview_text' => __( 'Main Navigation Font', 'viral' ),
			'preview_color' => 'dark',
			'font_family' => 'Lato',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#c2c2c2',
			'additional_css' => 'text-transform: uppercase;',
			'css_selectors' => '#secondary-navigation a, .top-right-side'
		),
		'home_title_font' => array(
			'preview_text' => __( 'Home and Single Title', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_size' => '22px',
			'font_variant' => '700',
			'font_color' => '#000000',
			'css_selectors' => '.latestPost .title a, .single-title, #respond h4, .total-comments, .postauthor h4'
		),
		'content_font' => array(
			'preview_text' => __( 'Content Font', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_size' => '16px',
			'font_variant' => 'normal',
			'font_color' => '#000000',
			'css_selectors' => 'body'
		),
		'sidebar_title' => array(
			'preview_text' => __( 'Sidebar Widget Title', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '16px',
			'font_color' => '#000000',
			'css_selectors' => '.sidebar .widget h3, #sidebar .widget h3 a, #sidebar .wpt_widget_content .tab_title a, #sidebar .wp_review_tab_widget_content .tab_title a'
		),
		'sidebar_font' => array(
			'preview_text' => __( 'Sidebar Font', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#3c4e5a',
			'css_selectors' => '#sidebar .widget, #sidebar .widget a'
		),
		'footer_title' => array(
			'preview_text' => __( 'Footer Widget Title', 'viral' ),
			'preview_color' => 'dark',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '16px',
			'font_color' => '#e4e4e4',
			'css_selectors' => '.footer-widgets h3, .footer-widgets .widget h3 a'
		),
		'footer_font' => array(
			'preview_text' => __( 'Footer Font', 'viral' ),
			'preview_color' => 'dark',
			'font_family' => 'Lato',
			'font_variant' => 'normal',
			'font_size' => '14px',
			'font_color' => '#888888',
			'css_selectors' => '.footer-widgets, .footer-widgets a, .copyrights'
		),
		'h1_headline' => array(
			'preview_text' => __( 'Content H1', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '28px',
			'font_color' => '#222222',
		'css_selectors' => 'h1'
		),
		'h2_headline' => array(
			'preview_text' => __( 'Content H2', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '24px',
			'font_color' => '#222222',
			'css_selectors' => 'h2'
		),
		'h3_headline' => array(
			'preview_text' => __( 'Content H3', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '22px',
			'font_color' => '#222222',
			'css_selectors' => 'h3'
		),
		'h4_headline' => array(
			'preview_text' => __( 'Content H4', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '20px',
			'font_color' => '#222222',
			'css_selectors' => 'h4'
		),
		'h5_headline' => array(
			'preview_text' => __( 'Content H5', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '18px',
			'font_color' => '#222222',
			'css_selectors' => 'h5'
		),
		'h6_headline' => array(
			'preview_text' => __( 'Content H6', 'viral' ),
			'preview_color' => 'light',
			'font_family' => 'Lato',
			'font_variant' => '700',
			'font_size' => '16px',
			'font_color' => '#222222',
			'css_selectors' => 'h6'
		)
	));
}
